%define debug_package %{nil}

%if 0%{?centos} == 7
%define python3_pkgversion 36
%endif

%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^libffi-9c61262e.so.8.1.0
%define _build_id_links none

%define	rel			1
%define VirtualEnvironment      %{name}-%{version}-%{rel}
%define VirtualEnvironmentPath  %{_prefix}/local/lib/PythonVirtualEnvironments

%if 0%{?centos} || 0%{?amzn}
%define __python                %(echo which python3 | scl enable rh-python38 -)
%else
%define __python                /usr/bin/python3
%endif

Name:           python-oletools
Version:        0.60.1
Release:        1%{?dist}
Summary:        Tools to analyze Microsoft OLE2 files

# oletools/*.py: BSD
# oletools/olevba*.py: BSD and MIT
# oletools/thirdparty/xxxswf/*.py: No license specified
# oletools/thirdparty/xglob/*.py: BSD
# oletools/thirdparty/tablestream/*.py: BSD
# oletools/thirdparty/zipfile27/*.py: Python
# oletools/thirdparty/msoffcrypto/*.py: MIT
License:        BSD and MIT and Python
URL:            https://www.decalage.info/python/oletools
#               https://github.com/decalage2/oletools/releases
#               https://github.com/nolze/msoffcrypto-tool/releases

%global         srcname oletools

%global         _description %{expand:
The python-oletools is a package of python tools from Philippe Lagadec
to analyze Microsoft OLE2 files (also called Structured Storage,
Compound File Binary Format or Compound Document File Format),
such as Microsoft Office documents or Outlook messages, mainly for
malware analysis, forensics and debugging.
It is based on the olefile parser.
See http://www.decalage.info/python/oletools for more info.
}

Source:        https://github.com/decalage2/oletools/archive/v%{version}/%{srcname}-%{version}.tar.gz

%if 0%{?amzn}
BuildRequires:  rh-python36-python-virtualenv
BuildRequires:  rh-python38-python rh-python38-python-devel
BuildRequires:  rust
Requires:       rh-python38-python
%endif

%if 0%{?centos} == 8 || 0%{?rhel} == 8
BuildRequires:  python3-virtualenv python38-devel python38
%endif

%if 0%{?centos} == 9 || 0%{?rhel} == 9
BuildRequires:  python3-virtualenv python3-devel python3
%endif

%if 0%{?centos} == 7 && 0%{?amzn} == 0
BuildRequires:  python36-virtualenv
BuildRequires:  rh-python38-python rh-python38-python-devel
Requires:       rh-python38-python
%endif

%if 0%{?fedora}
BuildRequires:  python3-virtualenv python3-devel
%endif

%description    %{_description}

%package -n python%{python3_pkgversion}-%{srcname}
Summary:        %{summary}
%{?python_provide:%python_provide python%{python3_pkgversion}-%{srcname}}

%description -n python%{python3_pkgversion}-%{srcname} %{_description}
Python3 version.

%package -n python-%{srcname}-doc
Summary:        Documentation files for %{name}
%{?python_provide:%python_provide python%{python3_pkgversion}-%{srcname}-doc}

%description -n python-%{srcname}-doc %{_description}

%prep
%setup -n %{srcname}-%{version}
sudo mkdir -p %{VirtualEnvironmentPath}
sudo chown %(id -u).%(id -g) %{VirtualEnvironmentPath}
cd %{VirtualEnvironmentPath}
rm -rf %{VirtualEnvironment}

%if 0%{?amzn}
echo virtualenv -p $(echo which python3.8 | scl enable rh-python38 -) %{VirtualEnvironment} | scl enable rh-python36 -
%endif

%if 0%{?centos}0%{?amzn} == 70
echo virtualenv-3 -p $(echo which python3 | scl enable rh-python38 -) %{VirtualEnvironment} | scl enable rh-python38 -
%endif

%if 0%{?centos} == 8
virtualenv-3 -p $(which python3.8) %{VirtualEnvironment}
%endif

%if 0%{?centos} == 9
virtualenv -p $(which python3) %{VirtualEnvironment}
%endif

%if 0%{?fedora}
virtualenv %{VirtualEnvironment}
%endif

%build
cd %{VirtualEnvironmentPath}/%{VirtualEnvironment}
for p in pip oletools
do
	sh -c "source bin/activate; pip3 install --upgrade \"$p\""
done

%install
%{__mkdir_p} %{buildroot}/%{VirtualEnvironmentPath}

pushd %{VirtualEnvironmentPath}
find %{VirtualEnvironment} | cpio -pdm %{buildroot}%{VirtualEnvironmentPath}
popd

mkdir -p $RPM_BUILD_ROOT%{_bindir}
pushd %{buildroot}%{VirtualEnvironmentPath}/%{VirtualEnvironment}/bin

for app in ezhexviewer ftguess mraptor msodde msoffcrypto-tool olebrowse oledir olefile \
	    oleid olemap olemeta oleobj oletimes olevba pcodedmp pyxswf rtfobj pcodedmp
do
	cat > $RPM_BUILD_ROOT%{_bindir}/$app << EOF
#!/bin/sh

%if 0%{?amzn} || 0%{?centos}0%{?amzn} == 70
echo %{VirtualEnvironmentPath}/%{VirtualEnvironment}/bin/$app "\$@" | scl enable rh-python%{python3_pkgversion} -
%else
exec %{VirtualEnvironmentPath}/%{VirtualEnvironment}/bin/$app "\$@"
%endif
EOF
	chmod 755 $RPM_BUILD_ROOT%{_bindir}/$app
done

popd

cp -p %{srcname}/thirdparty/xglob/LICENSE.txt  xglob-LICENSE.txt
cp -p %{srcname}/thirdparty/xxxswf/LICENSE.txt xxxswf-LICENSE.txt 

%files -n python%{python3_pkgversion}-%{srcname}
%license %{srcname}/LICENSE.txt xglob-LICENSE.txt xxxswf-LICENSE.txt
%doc %{srcname}/README.html
%{VirtualEnvironmentPath}/%{VirtualEnvironment}
%{_bindir}/*

%files -n python-%{srcname}-doc
%doc %{srcname}/doc/*
%doc cheatsheet

%changelog
* Mon May  9 2022 Lawrence R. Rogers <lrr@cert.org> - 0.60.1-1
* Release 0.60.1-1
	Version 0.60.1

* Sun May 09 2021 Robert Scheck <robert@fedoraproject.org> - 0.56.2-1
- Upgrade to 0.56.2 (#1958528)

* Sat Apr 03 2021 Robert Scheck <robert@fedoraproject.org> - 0.56.1-1
- Upgrade to 0.56.1 (#1945976)

* Tue Feb 02 2021 Robert Scheck <robert@fedoraproject.org> - 0.56-3
- Weak Python 2.7 pyparsing requirement for EPEL 7 correctly
- Add simple self-test mechanism to detect future weaking mistakes

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.56-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Jan 05 2021 Robert Scheck <robert@fedoraproject.org> - 0.56-1
- Upgrade to 0.56 (#1885099)

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.55-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jun 29 2020 Robert Scheck <robert@fedoraproject.org> 0.55-4
- Require python-setuptools during build-time explicitly

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 0.55-3
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.55-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Wed Dec 04 2019 Michal Ambroz <rebus AT_ seznam.cz> - 0.55-1
- bump to bugfix release 0.55

* Sun Nov 10 2019 Michal Ambroz <rebus AT_ seznam.cz> - 0.54.2-2
- use the msoffcrypto bundling only for python2 subpackage
- use python3-msoffcrypto for python3 package

* Fri Nov 08 2019 Michal Ambroz <rebus AT_ seznam.cz> - 0.54.2-1
- bump to release 0.54.2
- stop building the python2 for fc32+ epel8+
- add missing msoffcrypto python module
- fix python36 dependencies for EPEL7

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 0.51-10
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 0.51-9
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.51-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.51-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.51-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 0.51-5
- Rebuilt for Python 3.7

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.51-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Oct 23 2017 Robert Scheck <robert@fedoraproject.org> 0.51-3
- Correct line endings and remove shebang from non-executable
  python libraries (#1505374 #c5)
- Clarify python3 related scripts in %%description (#1505374 #c4)
- Correct summary of -doc subpackage (#1505374 #c2)

* Thu Oct 05 2017 Robert Scheck <robert@fedoraproject.org> 0.51-2
- Various spec file enhancements (#1471561)
- Added spec file conditionals to build for EPEL 7

* Thu Jun 22 2017 Michal Ambroz <rebus at, seznam.cz> 0.51-1
- bump to 0.51 release

* Thu Jun 22 2017 Michal Ambroz <rebus at, seznam.cz> 0.51-0.3.dev11.b4b52d22
- gaps in python3 detected, using python2 as default

* Thu Jun 15 2017 Michal Ambroz <rebu